@@ -3,7 +3,10 @@ import inspect
 
 from pywebvue import App
 
-__version__ = "1.3.0"
+from trame.utils.version import get_version
+
+__version__ = get_version()
+
 
 NEXT_TRIGGER_ID = 0
 TRIGGER_MAP = {}
@@ -171,6 +174,7 @@ def update_state(key, value=None):
     """
     _app = get_app_instance()
     _app.set(key, value)
+    return value
 
 
 # -----------------------------------------------------------------------------
@@ -191,11 +195,14 @@ def get_state(*names):
         List of value matching the requested state property names
     """
     _app = get_app_instance()
-    results = []
-    for name in names:
-        results.append(_app.get(name))
 
-    return results
+    if len(names):
+        results = []
+        for name in names:
+            results.append(_app.get(name))
+        return results
+
+    return _app.state
 
 
 def update_layout(layout):
@@ -307,8 +314,8 @@ def trigger_key(_fn):
 
 def change(*_args, **_kwargs):
     """
-    @change decorator allow to register a function in a way that it will be
-    automatically called when the given list of state names get modified.
+    The @change decorator allows us to register a function so that it will be
+    automatically called when the given list of state names gets modified.
 
     The decorated function is passed the full state as *kwarg when possible.
     This means you should have a method profile similar to `fn(..., *kwargs)`
